thorn.app — Thorn 1.3.0 documentation

# thorn.app

class `thorn.app.` `Thorn`(dispatcher=None, set_as_current=True)
  `Dispatcher`
  `Event`
  `ModelEvent`
  `Request`
  `Settings`
  `Subscriber`
  `Subscribers`
  `autodetect_env`(apply=<operator.methodcaller object>)
  `config`
  `dispatcher`
  `dispatchers` = {u'default': u'thorn.dispatch.base:Dispatcher', u'celery': u'thorn.dispatch.celery:Dispatcher', u'disabled': u'thorn.dispatch.disabled:Dispatcher'}
  `env`
  `environments` = set([u'thorn.environment.django:DjangoEnv'])
  `event_cls` = u'thorn.events:Event'
  `hmac_sign`
  `model_event_cls` = u'thorn.events:ModelEvent'
  `model_reverser`
  `request_cls` = u'thorn.request:Request'
  `reverse`
  `set_current`()
  `set_default`()
  `settings`
  `settings_cls` = u'thorn.conf:Settings'
  `signals`
  `subclass_with_self`(Class, name=None, attribute=u'app', reverse=None, keep_reduce=False, **kw)

    Subclass an app-compatible class by setting its app attribute to this instance.

    App-compatible means the class has an ‘app’ attribute providing the default app, e.g.: `class Foo(object): app = None`.

    Parameters: | Class – The class to subclass. name – Custom name for the target subclass. attribute – Name of the attribute holding the app. Default is `"app"`. reverse – Reverse path to this object used for pickling purposes. E.g. for `app.AsyncResult` use `"AsyncResult"`. keep_reduce – If enabled a custom `__reduce__` implementation will not be provided.

  `webhook_model`